﻿/*
 * Last review by   : Yaser
 * Last review date : JUL-20-09
 */

using System;
namespace ERP.Business.DataTypes.Constants.Interfaces
{
    /// <summary>
    /// Base class for constant types
    /// </summary>
    /// <remarks>
    /// Constant Type: ID-Name types.
    /// these types are stored in the db and they doesnt effect the buissenes directly, they are second-level info.
    /// </remarks>
    [System.Runtime.Serialization.KnownType(typeof(ConstantBase))]
    [System.Runtime.Serialization.DataContract]
    public abstract class ConstantBase : BaseTypes.BaseType
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ConstantBase"/> class.
        /// </summary>
        public ConstantBase() { }

        /// <summary>
        /// Initializes a new instance of the <see cref="ConstantBase"/> class.
        /// </summary>
        /// <param name="id">The id.</param>
        public ConstantBase(Guid id) : base(id) { }

        #endregion

        #region Properties

        /// <summary>
        /// Name
        /// </summary>
        /// <value>The name.</value>
        [System.Runtime.Serialization.DataMember]
        public string Name
        {
            get;
            set;
        }

        /// <summary>
        /// Obsolete flag
        /// </summary>
        /// <value><c>true</c> if [obsolete flag]; otherwise, <c>false</c>.</value>
        [System.Runtime.Serialization.DataMember]
        public bool ObsoleteFlag
        {
            get;
            set;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Compares two objects and returns a value indicating whether one is less than, equal to, or greater than the other.
        /// </summary>
        /// <param name="x">The first object to compare.</param>
        /// <param name="y">The second object to compare.</param>
        /// <returns>
        /// A signed integer that indicates the relative values of <paramref name="x"/> and <paramref name="y"/>, as shown in the following table.Value Meaning Less than zero <paramref name="x"/> is less than <paramref name="y"/>. Zero <paramref name="x"/> equals <paramref name="y"/>. Greater than zero <paramref name="x"/> is greater than <paramref name="y"/>.
        /// </returns>
        /// <exception cref="T:System.ArgumentException">Neither <paramref name="x"/> nor <paramref name="y"/> implements the <see cref="T:System.IComparable"/> interface.-or- <paramref name="x"/> and <paramref name="y"/> are of different types and neither one can handle comparisons with the other. </exception>
        public override int Compare(object x, object y)
        {
            if (ERP.Framework.Components.Utilities.ComparingHelper.ComapringManager.CompareTypes(x, y))
                return ((ConstantBase)x).Name.CompareTo(((ConstantBase)y).Name);
            return -1;
        }

        #endregion
    }
}